% m-file: driver_rotating_3d_globe_Manual_06_arguments
% Examples in the Manual: 6. Optional arguments
% folder: private/fig06
%
% When using this driver or fuctions it calls, please cite the reference:
%  Bezdek A, Sebera J, 2013. MATLAB script for 3D visualizing geodata on a rotating globe.
%  Computers & geosciences 56, 127130. http://dx.doi.org/10.1016/j.cageo.2013.03.007

% Ales Bezdek, bezdek@asu.cas.cz, 1/2015
% 6/2016 update to new Matlab versions up to R2015a

%% Choosing and editing a colour scale: examples
model='egm2008'; nmax=500;    %selection of geopotential model
[lond,latd,gh]=compute_geopot_grids(model,nmax,'functional','gh');
[hc,hlab,name_png]=rotating_3d_globe(lond,latd,gh,...
   'radius',6378e3,'units','m',...
   'exaggeration_factor',1.3e4,...
   'coastlines',1,...
   'graph_label',sprintf('Geoid height (%s, nmax=%d)',upper(model),nmax),...
   'clbr_limits',[-90 90],'clbr_tick',-100:20:100,...
   'tn_width',200,...
   'azimuth',70,'elevation',-5,...
   'window_height',650);



%% Choosing and editing a colour scale: examples
model='egm2008'; nmax=500;    %selection of geopotential model
[lond,latd,gh]=compute_geopot_grids(model,nmax,'functional','gh');
[hc,hlab,name_png]=rotating_3d_globe(lond,latd,gh,...
   'radius',6378e3,'units','m',...
   'exaggeration_factor',1.3e4,...
   'coastlines',1,...
   'cptcmap_pm','BlueYellowRed',...
   'graph_label',sprintf('Geoid height (%s, nmax=%d)',upper(model),nmax),...
   'clbr_limits',[-90 90],'clbr_tick',-100:20:100,...
   'tn_width',200,...
   'azimuth',70,'elevation',-5,...
   'window_height',650);


%% Choosing and editing a colour scale: examples
model='egm2008'; nmax=500;    %selection of geopotential model
[lond,latd,gh]=compute_geopot_grids(model,nmax,'functional','gh');
[hc,hlab,name_png]=rotating_3d_globe(lond,latd,gh,...
   'radius',6378e3,'units','m',...
   'exaggeration_factor',1.3e4,...
   'coastlines',1,...
   'clrmap','hsv',...
   'graph_label',sprintf('Geoid height (%s, nmax=%d)',upper(model),nmax),...
   'clbr_limits',[-90 90],'clbr_tick',-100:20:100,...
   'tn_width',200,...
   'azimuth',70,'elevation',-5,...
   'window_height',650);

%% Choosing and editing a colour scale: examples
model='egm2008'; nmax=500;    %selection of geopotential model
[lond,latd,gh]=compute_geopot_grids(model,nmax,'functional','gh');
[hc,hlab,name_png]=rotating_3d_globe(lond,latd,gh,...
   'radius',6378e3,'units','m',...
   'exaggeration_factor',1.3e4,...
   'coastlines',1,...
   'clrmap','clrmap_byr1',...
   'graph_label',sprintf('Geoid height (%s, nmax=%d)',upper(model),nmax),...
   'clbr_limits',[-90 90],'clbr_tick',-100:20:100,...
   'tn_width',200,...
   'azimuth',70,'elevation',-5,...
   'window_height',650);

